Modules
Structs
- CuImage
- CuImage
Buffer Format - ImuPayload
- Standardized IMU payload carrying acceleration, angular velocity, and optional magnetometer data.
- ImuWith
MagPayload - Combined payload allowing optional magnetometer data.
- Magnetometer
Payload - Magnetometer payload split from the main IMU data for composition.
- Point
Cloud - Standardized PointCloud. note: the derive(Soa) will generate a PointCloudSoa struct that will store the data in a SoA format. The Soa format is appropriate for early pipeline operations like changing their frame of reference. important: The ToV of the points are not assumed to be sorted.
- Point
Cloud Soa - Point
Cloud SoaStorage